@@ -1,4 +1,4 @@
-COUNTRIES = (("countries",),{'type':str,'nargs':'*','help':"countries to work on",'metavar':'COUNTRY'})
+COUNTRIES = (("countries",),{'type':str,'nargs':'+','help':"countries to work on",'metavar':'COUNTRY'})
 OVERPASS = (("-u","--overpass-url"),{'type':str,'dest':'overpass_url','help':"define url for Overpass API to be URL",'metavar':'URL'})
 NOGT = (("-g","--no-graph-tool"),{'action':'store_true','dest':'no_gt','default':False,'help':"do not perform graph_tool tests"})
 URL = (("-d","--download-url"),{'type':str,'dest':'url','help':"define url for download directory to be URL",'metavar':'URL'})
@@ -27,7 +27,7 @@ def extract_cache_all(overpass_url,countries):
         file_name_out = "graph."+country+".nx"
         extract_cache(file_name_in,file_name_out,overpass_url,area=None,around=1000,eps=0.01,safe_dist=100,penalize=20)
 
-def extract_osm_all(countries,conserve_mem):
+def extract_osm_all(countries,conserve_mem=False):
     from limic.extract import extract_osm
     for country in countries:
         file_name_in = country+"-latest.osm.bz2"
