@@ -73,7 +73,7 @@ def astar_npz(g,source_id=None,target_id=None):
     id2edges = g['id2edges']
     edges_weight = g['edges_weight']
     edges_neighbor = g['edges_neighbor']
-    edges_air = g['edges_air']
+    edges_air = g['edges_type']
     source, target = locate_by_id(ids,source_id,target_id)
     try:
         path = astar_path_npz(lat, long,id2edges,edges_weight,edges_neighbor,source,target)
@@ -92,7 +92,7 @@ def astar_npz(g,source_id=None,target_id=None):
                     dist = edges_weight[j]
                     air = edges_air[j]
                     cost += dist
-                    dpath.append(index2node(cost,dist,air,path[i]))
+                    dpath.append(index2node(cost,dist,air < 0,path[i]))
                     break
         return cost,dpath
     else:
@@ -149,8 +149,8 @@ def astar_nx(g,source_id=None,target_id=None):
             ggg = g[path[i-1]][path[i]]
             dist = ggg['weight']
             cost += dist
-            air = ggg['air']
-            dpath.append((cost,dist,air)+path[i])
+            air = ggg['type']
+            dpath.append((cost,dist,air < 0)+path[i])
         return cost,dpath
     except NetworkXNoPath as e:
         cost = dist = distance(source,target)
@@ -196,10 +196,10 @@ def astar_gt(g,source_id=None,target_id=None):
     else:
         e = g.edge(g.vertex(pred[current]),g.vertex(current))
         dist = g.ep.weight[e]
-        air = True if g.ep.air[e] else False
+        air = True if g.ep.type[e] < 0 else False
     while True:
         i = int(current)
-        path.append((cost,dist,air,ids[i],lat[i],long[i]))
+        path.append((cost,dist,air < 0,ids[i],lat[i],long[i]))
         pre = g.vertex(pred[current])
         if pre == current:
             break
@@ -212,7 +212,7 @@ def astar_gt(g,source_id=None,target_id=None):
         else:
             e = g.edge(g.vertex(pre),g.vertex(current))
             dist = g.ep.weight[e]
-            air = True if g.ep.air[e] else False
+            air = True if g.ep.type[e] < 0 else False
     path.reverse()
     if len(path) < 2:
         assert(len(path)==1)
@@ -276,7 +276,7 @@ def astar_tower_direct(start,end,max_fly=1000,eps=0.01,safe_dist=100,penalty=20,
             return "node(f="+repr(self.f)+",g="+repr(self.g)+",tower="+repr(self.tower)+",origin="+repr(self.origin.tower.id if self.origin else self.origin)+")"
     from limic.overpass import find_all_neighbours
     from heapq import heappop, heappush, heapify
-    from limic.util import distance, verbosity
+    from limic.util import distance
     from math import inf
     latlon2id = {}
     minusid = [0]
@@ -284,16 +284,16 @@ def astar_tower_direct(start,end,max_fly=1000,eps=0.01,safe_dist=100,penalty=20,
     nodes = {start.id : start_node}
     todo = [start_node]
     while todo:
-        if verbosity >= 4: print("*******************\n"+str(todo)+"\n***************")
-        if verbosity >= 4: print("*******************\n"+str(sorted(todo))+"\n***************")
+        #if verbosity >= 4: print("*******************\n"+str(todo)+"\n***************")
+        #if verbosity >= 4: print("*******************\n"+str(sorted(todo))+"\n***************")
         current = heappop(todo)
-        if verbosity >= 2: print("visiting",current.f,current.tower.id,current.tower.latlon)
-        if verbosity >= 2: print("full node",current)
+        #if verbosity >= 2: print("visiting",current.f,current.tower.id,current.tower.latlon)
+        #if verbosity >= 2: print("full node",current)
         if current.tower.id == end.id:
             return reconstruct_path_direct(current)
-        if verbosity >=2:
-            print("CURRENT PATH:\nnode(id:"+(",".join(map(str,reconstruct_path(current)[1])))+");out;")
-            print("FRONT:\nnode(id:"+(",".join(map(lambda n:str(n.tower.id),todo)))+");out;")
+        #if verbosity >=2:
+        #    print("CURRENT PATH:\nnode(id:"+(",".join(map(str,reconstruct_path(current)[1])))+");out;")
+        #    print("FRONT:\nnode(id:"+(",".join(map(lambda n:str(n.tower.id),todo)))+");out;")
         neighbours = find_all_neighbours(current.tower, max_fly, eps, safe_dist, minusid, latlon2id, penalty)
         for neighbour in neighbours:
             g = current.g+neighbour.dist
@@ -306,10 +306,10 @@ def astar_tower_direct(start,end,max_fly=1000,eps=0.01,safe_dist=100,penalty=20,
                 neighbour_node.g = g
                 neighbour_node.f = g+distance(neighbour.tower.latlon,end.latlon)*prec
                 if must_add:
-                    if verbosity >= 3: print("added",neighbour_node)
+                    #if verbosity >= 3: print("added",neighbour_node)
                     heappush(todo,neighbour_node)
-                else:
-                    if verbosity >= 3: print("modified",neighbour_node)
+                #else:
+                    #if verbosity >= 3: print("modified",neighbour_node)
                 heapify(todo)
     return None,[(0.,0.,False,start.id,start.latlon[0],start.latlon[1]),(float('inf'),start_node.f,True,end.id,end.latlon[0],end.latlon[1])]
 
@@ -320,10 +320,10 @@ def astar_direct(start,end):
     return astar_tower_direct(start_tower,end_tower)
     
 def route_direct(file_name,source_id=None,target_id=None,out_file=None,overpass_url=None,disk_cache=False,visualize=False):
-    from limic.util import start, end, status, file_size, load_pickled, save_pickled, save_path, set_disk_cache, replace
+    from limic.util import start, end, status, file_size, load_pickled, save_pickled, save_path, options, replace
     if disk_cache:
         start("Using disk cache",file_name)
-        set_disk_cache(file_name)
+        set_option('disk_cache',file_name)
     from limic.overpass import region, set_server
     if disk_cache:
         status("OK")
