@@ -1,4 +1,4 @@
-COUNTRIES = (("countries",),{'type':str,'nargs':'*','help':"countries to route on",'metavar':'COUNTRY'})
+COUNTRIES = (("countries",),{'type':str,'nargs':'+','help':"countries to route on",'metavar':'COUNTRY'})
 GRAPH = (("graph_file",),{'type':str,'help':"use graph file GRAPH",'metavar':'GRAPH'})
 HTML = (("html_file",),{'type':str,'help':"use rendered HTML file",'metavar':'HTML'})
 RHOST = (("--render-host",),{'type':str,'dest':'r_host','default':'localhost','help':"render hostname (default: localhost)",'metavar':'HOST'})
@@ -11,34 +11,28 @@ OSM = (("--osm",),{'action':'store_true','dest':'osm','default':False,'help':"pr
 NOBROWSER = (("-n","--no-browser"),{'action':'store_true','dest':'no_browser','default':False,'help':"do not open html in browser (headless)"})
 URL = (("-d","--download-url"),{'type':str,'dest':'url','help':"define url for download directory to be URL",'metavar':'URL'})
 SHOW = (("-l","--list"),{'action':'store_true','dest':'show','default':False,'help':"list available countries (default: False)"})
+CONSERVEMEM = (("-c","--conserve-memory"),{'action':'store_true','dest':'conserve_mem','default':False,'help':"lower memory usage but higher runtime"})
 
 CONFIG = [
-    ("auto",{'help':"start HTTP server for given COUNTRY (default: Europe)",'args':[SHOW,URL,NOBROWSER,HOST,PORT,PREFIX,RHOST,RPORT,RPREFIX,OSM,COUNTRIES]}),
+    ("auto",{'help':"start HTTP server for given COUNTRY (default: Europe)",'args':[SHOW,URL,CONSERVEMEM,NOBROWSER,HOST,PORT,PREFIX,RHOST,RPORT,RPREFIX,OSM,COUNTRIES]}),
     ("nx",{'help':"start HTTP server for given GRAPH and rendered HTML file",'args':[SHOW,URL,NOBROWSER,HOST,PORT,PREFIX,RHOST,RPORT,RPREFIX,GRAPH,HTML]}),
 ]
 
-def serve_auto(countries,host="localhost",port=5000,prefix="",osm=False,url=None,show=False,no_browser=False,r_host="localhost",r_port=5000,r_prefix=""):
+def serve_auto(countries,host="localhost",port=5000,prefix="",osm=False,url=None,show=False,no_browser=False,r_host="localhost",r_port=5000,r_prefix="",conserve_mem=False):
     from limic.download import common, download_graph, download_merged, download_osm
     from limic.init import extract_osm_all, merge_all
     from limic.render import render_nx
     graph_file = None
+    countries, url = common(countries=countries,url=url,show=show,osm=osm)
     if osm:
         download_osm(countries=countries,url=url)
-        countries, url = common(countries=countries,url=url,show=show,osm=osm)
-        extract_osm_all(countries=countries)
-    elif not countries:
-        _, url = common(countries=countries,url=url,show=show,osm=osm)
-        countries = []
-        download_merged(suffixes=("nx",),url=url)
+        extract_osm_all(countries=countries,conserve_mem=conserve_mem)
     else:
-        countries, url = common(countries=countries,url=url,show=show,osm=osm)
         download_graph(suffix="nx",countries=countries,url=url,show=show)
     if len(countries) > 1 :
         merge_all(countries)
     if len(countries) == 1:
         graph_file = "graph."+countries[0]+".nx"
-    else:
-        graph_file = "merged.Europe.nx"
     html_file = graph_file[:-2]+"html"
     serve_nx(graph_file,html_file,host=host,port=port,prefix=prefix,url=url,show=show,no_browser=no_browser,r_host=r_host,r_port=r_port,r_prefix=r_prefix)
         
